<?php

add_action( 'admin_init', 'theme_options_init' );
add_action( 'admin_menu', 'theme_options_add_page' );

/**
 * Init plugin options to white list our options
 */
function theme_options_init(){
	register_setting( 'brandnewday_options', 'brandnewday_theme_options', 'theme_options_validate' );
}

/**
 * Load up the menu page
 */
function theme_options_add_page() {
	add_theme_page( __( 'Theme Options', 'brandnewdaytheme' ), __( 'Theme Options', 'brandnewdaytheme' ), 'edit_theme_options', 'theme_options', 'theme_options_do_page' );
} 
 
/**
 * Create arrays for our theme styles and sidebar options
 */

$radio_options = array(
	'daylight' => array(
		'value' => 'daylight',
		'label' => __( 'Daylight', 'brandnewdaytheme' )
	),
	'nightlight' => array(
		'value' => 'nightlight',
		'label' => __( 'Nightlight', 'brandnewdaytheme' )
	),
	'winterlight' => array(
		'value' => 'winterlight',
		'label' => __( 'Winterlight', 'brandnewdaytheme' )
	)
);

$radio2_options = array(
	'right' => array(
		'value' => 'right',
		'label' => __( 'Right Sidebar', 'brandnewdaytheme' )
	),
	'left' => array(
		'value' => 'left',
		'label' => __( 'Left Sidebar', 'brandnewdaytheme' )
	),
	'none' => array(
		'value' => 'none',
		'label' => __( 'No Sidebar', 'brandnewdaytheme' )
	)
);

/**
 * Create the options page
 */
function theme_options_do_page() {
	global $radio_options, $radio2_options;

	if ( ! isset( $_REQUEST['settings-updated'] ) )
		$_REQUEST['settings-updated'] = false;

	?>
	<div class="wrap">
		<?php screen_icon(); echo "<h2>" . get_current_theme() . __( ' Theme Options', 'brandnewdaytheme' ) . "</h2>"; ?>

		<?php if ( false !== $_REQUEST['settings-updated'] ) : ?>
		<div class="updated fade"><p><strong><?php _e( 'Options saved', 'brandnewdaytheme' ); ?></strong></p></div>
		<?php endif; ?>

		<form method="post" action="options.php">
			<?php settings_fields( 'brandnewday_options' ); ?>
			<?php $options = get_option( 'brandnewday_theme_options' ); ?>

			<table class="form-table">

				<?php
				/**
				 * Theme Style
				 */
				?>
				<tr valign="top"><th scope="row"><strong><?php _e( 'Theme Style', 'brandnewdaytheme' ); ?></strong></th>
					<td>
						<fieldset><legend class="screen-reader-text"><span><?php _e( 'Theme Style', 'brandnewdaytheme' ); ?></span></legend>
						<?php
							if ( ! isset( $checked ) )
								$checked = '';
							foreach ( $radio_options as $option ) {
								$radio_setting = $options['radioinput'];

								if ( '' != $radio_setting ) {
									if ( $options['radioinput'] == $option['value'] ) {
										$checked = "checked=\"checked\"";
									} else {
										$checked = '';
									}
								}
								?>
								<div style="width: 240px; float: left; margin-right: 30px; text-align: center;">
									<label class="description"><img src="<?php echo get_template_directory_uri() . '/images/' . $option['label'] . '.png'; ?>" style="width: 240px;" alt="<?php echo $option['label']; ?> Style" /><br /><input type="radio" name="brandnewday_theme_options[radioinput]" value="<?php esc_attr_e( $option['value'] ); ?>" <?php echo $checked; ?> /> <?php echo $option['label']; ?></label>
								</div>
								<?php
							}
						?>
						</fieldset>
					</td>
				</tr>
				
				<?php
				/**
				 * Sidebar Options
				 */
				?>
				<tr valign="top"><th scope="row"><strong><?php _e( 'Sidebar Options', 'brandnewdaytheme' ); ?></strong></th>
					<td>
						<fieldset><legend class="screen-reader-text"><span><?php _e( 'Sidebar Options', 'brandnewdaytheme' ); ?></span></legend>
						<?php
							if ( ! isset( $checked ) )
								$checked = '';
							foreach ( $radio2_options as $option ) {
								$radio_setting = $options['radioinput2'];

								if ( '' != $radio_setting ) {
									if ( $options['radioinput2'] == $option['value'] ) {
										$checked = "checked=\"checked\"";
									} else {
										$checked = '';
									}
								}
								?>
								<label class="description"><input type="radio" name="brandnewday_theme_options[radioinput2]" value="<?php esc_attr_e( $option['value'] ); ?>" <?php echo $checked; ?> /> <?php echo $option['label']; ?></label><br />
						<?php
							}
						?>
						</fieldset>
					</td>
				</tr>
				
				<?php
				/**
				 * Remove Search
				 */
				?>
				<tr valign="top"><th scope="row"><strong><?php _e( 'Remove Search', 'brandnewdaytheme' ); ?></strong></th>
					<td>
						<input id="brandnewday_theme_options[option2]" name="brandnewday_theme_options[option2]" type="checkbox" value="1" <?php checked( '1', $options['option2'] ); ?> />
						<label class="description" for="brandnewday_theme_options[option2]"><?php _e( 'Remove search bar from header', 'brandnewdaytheme' ); ?></label>
					</td>
				</tr>
				
				<?php
				/**
				 * Enable Simple Blog Mode
				 */
				?>
				<tr valign="top"><th scope="row"><strong><?php _e( 'Enable Simple Blog Mode', 'brandnewdaytheme' ); ?></strong></th>
					<td>
						<input id="brandnewday_theme_options[option1]" name="brandnewday_theme_options[option1]" type="checkbox" value="1" <?php checked( '1', $options['option1'] ); ?> />
						<label class="description" for="brandnewday_theme_options[option1]"><?php _e( 'Remove the sidebar, search bar and narrow the content column', 'brandnewdaytheme' ); ?></label>
					</td>
				</tr>

				<?php
				/**
				 * Custom CSS
				 */
				?>
				<tr valign="top"><th scope="row"><strong><?php _e( 'Custom CSS', 'brandnewdaytheme' ); ?></strong></th>
					<td>
						<textarea id="brandnewday_theme_options[sometextarea]" class="large-text" cols="50" rows="10" name="brandnewday_theme_options[sometextarea]"><?php echo esc_textarea( $options['sometextarea'] ); ?></textarea>
						<label class="description" for="brandnewday_theme_options[sometextarea]"><?php _e( 'Add any custom CSS here so it will persist through theme updates.', 'brandnewdaytheme' ); ?></label>
					</td>
				</tr>
			</table>

			<p class="submit">
				<input type="submit" class="button-primary" value="<?php _e( 'Save Options', 'brandnewdaytheme' ); ?>" />
			</p>
		</form>
	</div>
	<?php
}

/**
 * Sanitize and validate input. Accepts an array, return a sanitized array.
 */
function theme_options_validate( $input ) {
	global $radio_options, $radio2_options;

	// Our Simple Blog value is either 0 or 1
	if ( ! isset( $input['option1'] ) )
		$input['option1'] = null;
	$input['option1'] = ( $input['option1'] == 1 ? 1 : 0 );
	
	// Our Remove Search value is either 0 or 1
	if ( ! isset( $input['option2'] ) )
		$input['option2'] = null;
	$input['option2'] = ( $input['option2'] == 1 ? 1 : 0 );

	// Our Theme Styles must actually be in our array of radio options
	if ( ! isset( $input['radioinput'] ) )
		$input['radioinput'] = null;
	if ( ! array_key_exists( $input['radioinput'], $radio_options ) )
		$input['radioinput'] = null;
		
	// Our Sidebar Options must actually be in our array of radio options
	if ( ! isset( $input['radioinput2'] ) )
		$input['radioinput2'] = null;
	if ( ! array_key_exists( $input['radioinput2'], $radio2_options ) )
		$input['radioinput2'] = null;

	// Say our textarea option must be safe text with the allowed tags for posts
	$input['sometextarea'] = wp_filter_post_kses( $input['sometextarea'] );

	return $input;
}

// adapted from http://planetozh.com/blog/2009/05/handling-plugins-options-in-wordpress-28-with-register_setting/